==> apache-cxf-3.4.10.tar.gz: apache-cxf-3.4.10/samples/jax_rs/tracing_brave/src/main/java/demo/jaxrs/tracing/client/Client.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package demo.jaxrs.tracing.client;

import java.util.Arrays;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.tracing.brave.jaxrs.BraveClientProvider;

import demo.jaxrs.tracing.server.CatalogTracing;

public final class Client {
    private Client() {
    }

    public static void main(final String[] args) throws Exception {
        try (final CatalogTracing tracing = new CatalogTracing("catalog-client")) {
            final BraveClientProvider provider = new BraveClientProvider(tracing.getHttpTracing());
    
            final Response response = WebClient
                .create("http://localhost:9000/catalog", Arrays.asList(provider))
                .accept(MediaType.APPLICATION_JSON)
                .get();
    
            System.out.println(response.readEntity(String.class));
            response.close();
        }
    }
}

==> apache-cxf-4.0.6.tar.gz: apache-cxf-4.0.6/samples/jax_rs/tracing_brave/src/main/java/demo/jaxrs/tracing/client/Client.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package demo.jaxrs.tracing.client;

import java.util.Arrays;

import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;

import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.tracing.brave.jaxrs.BraveClientProvider;

import demo.jaxrs.tracing.server.CatalogTracing;

public final class Client {
    private Client() {
    }

    public static void main(final String[] args) throws Exception {
        try (final CatalogTracing tracing = new CatalogTracing("catalog-client")) {
            final BraveClientProvider provider = new BraveClientProvider(tracing.getHttpTracing());
    
            final Response response = WebClient
                .create("http://localhost:9000/catalog", Arrays.asList(provider))
                .accept(MediaType.APPLICATION_JSON)
                .get();
    
            System.out.println(response.readEntity(String.class));
            response.close();
        }
    }
}
